# pycurrency-convertor

This is a simple python packaghe to convert currency

## Issues

You can report the bugs at the [issue tracker](https://github.com/vaibhavsingh97/StalkPy/issues)

## License

Built with ♥ by Vaibhav Singh([@vaibhavsingh97](https://github.com/vaibhavsingh97)) under [MIT License](https://vaibhavsingh97.mit-license.org/)

You can find a copy of the License at <https://vaibhavsingh97.mit-license.org/>